@@ -1,10 +1,10 @@
-/* $Id: SUPR0IdcClientInternal.h 100877 2015-06-09 14:23:56Z bird $ */
+/* $Id: SUPR0IdcClientInternal.h 118839 2017-10-28 15:14:05Z bird $ */
 /** @file
  * VirtualBox Support Driver - Internal header for the IDC client library.
  */
 
 /*
- * Copyright (C) 2008-2015 Oracle Corporation
+ * Copyright (C) 2008-2017 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -31,27 +31,8 @@
 #include <iprt/assert.h>
 
 #ifdef RT_OS_WINDOWS
-# if (_MSC_VER >= 1400) && !defined(VBOX_WITH_PATCHED_DDK)
-#  include <iprt/asm.h>
-#  define _InterlockedExchange           _InterlockedExchange_StupidDDKVsCompilerCrap
-#  define _InterlockedExchangeAdd        _InterlockedExchangeAdd_StupidDDKVsCompilerCrap
-#  define _InterlockedCompareExchange    _InterlockedCompareExchange_StupidDDKVsCompilerCrap
-#  define _InterlockedAddLargeStatistic  _InterlockedAddLargeStatistic_StupidDDKVsCompilerCrap
-#  pragma warning(disable : 4163)
-RT_C_DECLS_BEGIN
-#  include <ntddk.h>
-RT_C_DECLS_END
-#  pragma warning(default : 4163)
-#  undef  _InterlockedExchange
-#  undef  _InterlockedExchangeAdd
-#  undef  _InterlockedCompareExchange
-#  undef  _InterlockedAddLargeStatistic
-# else
-RT_C_DECLS_BEGIN
-#  include <ntddk.h>
-RT_C_DECLS_END
-# endif
-#endif /* RT_OS_WINDOWS */
+# include <iprt/nt/ntddk.h>
+#endif
 
 
 /**
