@@ -1,10 +1,10 @@
-/* $Id: VBoxNetAdpInternal.h 103166 2015-10-07 13:54:00Z vushakov $ */
+/* $Id: VBoxNetAdpInternal.h 118839 2017-10-28 15:14:05Z bird $ */
 /** @file
  * VBoxNetAdp - Network Filter Driver (Host), Internal Header.
  */
 
 /*
- * Copyright (C) 2008-2015 Oracle Corporation
+ * Copyright (C) 2008-2017 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -13,6 +13,15 @@
  * Foundation, in version 2 as it comes in the "COPYING" file of the
  * VirtualBox OSE distribution. VirtualBox OSE is distributed in the
  * hope that it will be useful, but WITHOUT ANY WARRANTY of any kind.
+ *
+ * The contents of this file may alternatively be used under the terms
+ * of the Common Development and Distribution License Version 1.0
+ * (CDDL) only, as it comes in the "COPYING.CDDL" file of the
+ * VirtualBox OSE distribution, in which case the provisions of the
+ * CDDL are applicable instead of those of the GPL.
+ *
+ * You may elect to license modified versions of this file under the
+ * terms and conditions of either the GPL or the CDDL or both.
  */
 
 #ifndef ___VBoxNetAdpInternal_h___
@@ -76,7 +85,7 @@ enum VBoxNetAdpState
     kVBoxNetAdpState_Invalid,
     kVBoxNetAdpState_Transitional,
     kVBoxNetAdpState_Active,
-    kVBoxNetAdpState_U32Hack = 0xFFFFFFFF
+    kVBoxNetAdpState_32BitHack = 0x7FFFFFFF
 };
 typedef enum VBoxNetAdpState VBOXNETADPSTATE;
 
