@@ -1,4 +1,4 @@
-/* $Id: VBoxPci-linux.c 122536 2018-05-07 14:07:18Z michael $ */
+/* $Id: VBoxPci-linux.c 123648 2018-07-12 09:42:44Z michael $ */
 /** @file
  * VBoxPci - PCI Driver (Host), Linux Specific Code.
  */
@@ -41,7 +41,7 @@
 #include <iprt/string.h>
 #include <iprt/mem.h>
 
-#include "VBoxPciInternal.h"
+#include "../VBoxPciInternal.h"
 
 #ifdef VBOX_WITH_IOMMU
 # include <linux/dmar.h>
